@@ -7,12 +7,6 @@ from mongoengine.document import Document
 from rest_framework import serializers
 from mongoengine.fields import ObjectId
 
-import sys
-
-if sys.version_info[0] >= 3:
-    def unicode(val):
-        return str(val)
-
 
 class MongoDocumentField(serializers.WritableField):
     MAX_RECURSION_DEPTH = 5  # default value of depth
@@ -53,12 +47,11 @@ class MongoDocumentField(serializers.WritableField):
         Models to natives
         Recursion for (embedded) objects
         """
-
         if isinstance(obj, BaseDocument):
             # Document, EmbeddedDocument
             if depth == 0:
                 # Return primary key if exists, else return default text
-                return str(getattr(obj, 'pk', "Max recursion depth exceeded"))
+                return smart_str(getattr(obj, 'pk', 'Max recursion depth exceeded'))
             return self.transform_document(obj, depth)
         elif isinstance(obj, dict):
             # Dictionaries
@@ -69,7 +62,7 @@ class MongoDocumentField(serializers.WritableField):
         elif obj is None:
             return None
         else:
-            return unicode(obj) if isinstance(obj, ObjectId) else obj
+            return smart_str(obj) if isinstance(obj, ObjectId) else obj
 
 
 class ReferenceField(MongoDocumentField):
@@ -92,7 +85,7 @@ class ReferenceField(MongoDocumentField):
         return instance
 
     def to_native(self, obj):
-        return self.transform_object(obj, self.depth-1)
+        return self.transform_object(obj, self.depth - 1)
 
 
 class ListField(MongoDocumentField):
@@ -103,7 +96,7 @@ class ListField(MongoDocumentField):
         return self.model_field.to_python(value)
 
     def to_native(self, obj):
-        return self.transform_object(obj, self.depth)
+        return self.transform_object(obj, self.depth - 1)
 
 
 class EmbeddedDocumentField(MongoDocumentField):
@@ -125,7 +118,7 @@ class EmbeddedDocumentField(MongoDocumentField):
         if obj is None:
             return None
         else:
-            return self.model_field.to_mongo(obj)
+            return self.transform_object(obj, self.depth)
 
     def from_native(self, value):
         return self.model_field.to_python(value)
@@ -136,4 +129,4 @@ class DynamicField(MongoDocumentField):
     type_label = 'DynamicField'
 
     def to_native(self, obj):
-        return self.model_field.to_python(obj)
\ No newline at end of file
+        return self.model_field.to_python(obj)
