@@ -1,6 +1,5 @@
 from __future__ import unicode_literals
 import warnings
-from django.core.exceptions import ValidationError
 from mongoengine.errors import ValidationError
 from rest_framework import serializers
 from rest_framework import fields
@@ -165,7 +164,7 @@ class MongoEngineModelSerializer(serializers.ModelSerializer):
             mongoengine.BooleanField: fields.BooleanField,
             mongoengine.FileField: fields.FileField,
             mongoengine.ImageField: fields.ImageField,
-            mongoengine.ObjectIdField: fields.Field,
+            mongoengine.ObjectIdField: fields.WritableField,
             mongoengine.ReferenceField: ReferenceField,
             mongoengine.ListField: ListField,
             mongoengine.EmbeddedDocumentField: EmbeddedDocumentField,
